@@ -247,8 +247,6 @@ class Vertex:
                     break
             else:
                 raise AssertionError("entry_point %r is not a column." % entry_point)
-            assert entry_point.data_type == "Text"
-            assert not entry_point.drop
         assert isinstance(data_keys, list)
         if data_keys:
             for data_key in data_keys:
