@@ -106,20 +106,13 @@ def graph_from_config_dict(config: MutableMapping[str, Any]) -> Graph:
             for col in cols:
                 if col.name == entry_point_raw:
                     entry_point = col
-                    if entry_point.data_type != "Text":
-                        raise InvalidSpec(
-                            "entry_point %r must refer to Text column."
-                            % entry_point.name
-                        )
-                    elif entry_point.drop:
+                    if entry_point.drop:
                         raise InvalidSpec(
                             "entry_point %r cannot be dropped." % entry_point.name
                         )
                     break
             else:
-                raise InvalidSpec(
-                    "Column %r not found. Cannot be entry point." % entry_point_raw
-                )
+                raise InvalidSpec("entry_point column %r not found." % entry_point_raw)
         data_keys = v_raw.get("data_keys", [])
         v_drop = v_raw.get("drop", False)
         indexes = []
@@ -181,6 +174,7 @@ def graph_from_config_dict(config: MutableMapping[str, Any]) -> Graph:
 
     for vertex in vertices.values():
         col_resolver_and_validator(vertex.cols, vertices, enums, ctypes, vertex.drop)
+        entry_point_validator(vertex)
 
     edges: Dict[str, Edge] = OrderedDict()
     for e_name, e_raw in edges_raw.items():
@@ -291,6 +285,12 @@ def col_resolver_and_validator(
     ctypes: Dict[str, CompositeType],
     dropped: bool,
 ) -> None:
+    """
+    Mutates `cols` by resolving and setting the correct data_type.
+
+    Raises:
+        - InvalidSpec
+    """
     for col in cols:
         assert isinstance(col.data_type, str)
         is_array = False
@@ -336,6 +336,42 @@ def col_resolver_and_validator(
             col.data_type = Array(col.data_type)
 
 
+def entry_point_validator(vertex: Vertex) -> None:
+    """
+    Validates that the entry_point references a Text or CompositeType of texts,
+    and if the latter, that it isn't dropped.
+
+    Raises:
+        - InvalidSpec
+    """
+    if not vertex.entry_point:
+        return
+    entry_point_dt = vertex.entry_point.data_type
+    if isinstance(entry_point_dt, CompositeType):
+        if entry_point_dt.drop and not vertex.drop:
+            raise InvalidSpec(
+                "entry_point %r cannot reference dropped composite type %r."
+                % (vertex.entry_point.name, entry_point_dt.name)
+            )
+        for field_name, field_data_type in entry_point_dt.fields:
+            if field_data_type != "Text":
+                raise InvalidSpec(
+                    "entry_point %r requires %r.%r to be a Text column."
+                    % (
+                        vertex.entry_point.name,
+                        entry_point_dt.name,
+                        field_name,
+                    )
+                )
+    elif entry_point_dt == "Text":
+        pass
+    else:
+        raise InvalidSpec(
+            "entry_point %r must reference Text or CompositeType of Texts."
+            % vertex.entry_point.name
+        )
+
+
 def data_type_resolver(
     data_type_raw: str,
     vertices: Dict[str, Vertex],
@@ -358,7 +394,7 @@ def data_type_resolver(
         ref_name = data_type_raw[len("enum:") :]
         if ref_name not in enums:
             raise InvalidSpec("Undefined enum: %r" % ref_name)
-        data_type = ctypes[ref_name]
+        data_type = enums[ref_name]
     elif data_type_raw.startswith("ctype:"):
         ref_name = data_type_raw[len("ctype:") :]
         if ref_name not in ctypes:
