@@ -288,8 +288,13 @@ def random_vshard() -> int:
     return random.randint(-32768, 32767)
 
 
-def entry_point_to_vshard(entry_point_val: str) -> int:
-    hashed_val = hashlib.sha1(entry_point_val.encode("utf-8")).digest()
+def entry_point_to_vshard(entry_point_val: Union[str, Tuple[str, ...]]) -> int:
+    if isinstance(entry_point_val, tuple):
+        entry_point_val = "".join(entry_point_val)
+    else:
+        assert isinstance(entry_point_val, str), type(entry_point_val)
+    entry_point_encoded = entry_point_val.encode("utf-8")
+    hashed_val = hashlib.sha1(entry_point_encoded).digest()
     pair_of_bytes = hashed_val[:2]
     return struct.unpack("<h", pair_of_bytes)[0]
 
@@ -355,8 +360,6 @@ class EntryPointMixin:
             assert entry_point_val is not None, (
                 "Entry point %r must be set." % entry_point_val
             )
-            # Redundant check (already enforced by grapdb)
-            assert isinstance(entry_point_val, str)
             self.gid = literal((None, entry_point_to_vshard(entry_point_val)))
         if isinstance(self.gid, BindParameter):
             return self.gid.value[1]
@@ -467,15 +470,15 @@ class ShardMapper:
                 if column.name not in {"gid", "src"}:
                     continue
                 if operator == eq:
-                    assert isinstance(value, tuple)
-                    assert len(value) == 2
+                    assert isinstance(value, tuple), value
+                    assert len(value) == 2, value
                     vshard = value[1]
                     shards.add(self.jump_hash(vshard))
                 elif operator == operators.in_op:
-                    assert operator == operators.in_op
+                    assert operator == operators.in_op, operator
                     for gid in value:
-                        assert isinstance(gid, tuple)
-                        assert len(gid) == 2
+                        assert isinstance(gid, tuple), gid
+                        assert len(gid) == 2, gid
                         vshard = gid[1]
                         shards.add(self.jump_hash(vshard))
                 else:
@@ -484,7 +487,14 @@ class ShardMapper:
                 issubclass(ent_class, EntryPointMixin)
                 and column.name == ent_class._entry_point
             ):  # pylint: disable=W0212
-                shards.add(self.jump_hash(entry_point_to_vshard(value)))
+                if operator == eq:
+                    shards.add(self.jump_hash(entry_point_to_vshard(value)))
+                elif operator == operators.in_op:
+                    assert operator == operators.in_op, operator
+                    for entry_point in value:
+                        shards.add(self.jump_hash(entry_point_to_vshard(entry_point)))
+                else:
+                    assert False, "Unsupported operator %r" % operator
         if not shards:
             logger.warning("query_chooser: querying all shards.")
             shards = self.shards_set
