@@ -13,7 +13,8 @@ from code_writer import CodeWriter, fmt_pascal
 
 
 preamble = """\
-from typing import List, Tuple
+import datetime
+from typing import List, NamedTuple
 
 from sqlalchemy import (  # pylint: disable=E0401,W0611
     BigInteger,
@@ -68,7 +69,7 @@ def generate_user_types_module(graph: Graph) -> str:
         cw.emit_list(
             [repr(value) for value in enum.values],
             ("[", "]"),
-            "_{}_values =".format(enum.name),
+            "_{}_values = ".format(enum.name),
         )
         cw.emit("{0} = Enum(*_{0}_values, name='{0}')".format(enum.name))
 
@@ -323,9 +324,12 @@ def graph_type_to_mypy_type(data_type: DataType) -> str:
     elif isinstance(data_type, Enum):
         return "str"
     elif isinstance(data_type, CompositeType):
-        return "Tuple[{}]".format(
-            ", ".join(graph_type_to_mypy_type(field[1]) for field in data_type.fields)
-        )
+        named_tuple_fields = [
+            '("{}", {})'.format(field[0], graph_type_to_mypy_type(field[1]))
+            for field in data_type.fields]
+        return 'NamedTuple("{}", [{}])'.format(
+            data_type.name,
+            ", ".join(named_tuple_fields))
     elif isinstance(data_type, Array):
         return "List[{}]".format(graph_type_to_mypy_type(data_type.element_type))
     else:
